import { ComponentPropsWithoutRef } from 'react';
import { ComponentType } from 'react';
import { JSX as JSX_2 } from 'react/jsx-runtime';
import { ReactNode } from 'react';

/**
 * Dialogs have `RequiredDialogProps` and any number of other additional props.
 *
 * The additional dialog props type can be used to create types matching these
 * additional props.
 *
 * For example:
 * ```ts
 * const MyDialogComponent = (props: RequiredDialogProps & { variant: 'large' | 'small'}) => { ... }
 *
 * const MyAdditionalProps = AdditionalDialogProps<typeof MyDialogComponent>
 * // MyAdditionalProps = { variant: 'large' | 'small' } *
 * ```
 */
export declare type AdditionalDialogProps<T extends React.FunctionComponent<any>> = Omit<ComponentPropsWithoutRef<T>, keyof RequiredDialogProps>;

/**
 * All dialogs must implement the `RequiredDialogProps`.
 *
 * For example:
 * ```ts
 * const MyDialogComponent = (props: RequiredDialogProps & { variant: 'large' | 'small'}) => { ... }
 *
 * ```
 */
export declare type RequiredDialogProps = {
    open: boolean;
    onModalResult: (modalResult: string) => void;
};

declare type ShowDialogFunc = <T extends RequiredDialogProps>(DialogComponent: ComponentType<T>, onModalResult: (modalResult: string) => void, dialogProps?: Omit<T, keyof RequiredDialogProps>) => void;

/**
 * Assists with modal dialogs by providing requirements for the `useShowDialog` hook.
 */
export declare const ShowDialogProvider: ({ children }: {
    children?: ReactNode;
}) => JSX_2.Element;

export declare const useShowDialog: () => ShowDialogFunc;

export { }
